@@ -36,7 +36,7 @@ void LineChartCore::setPointRadius(qreal pointRadius)
     {
         m_pointRadius = pointRadius;
         triggerUpdate();
-        emit pointRadiusChanged();
+        Q_EMIT pointRadiusChanged();
     }
 }
 
@@ -45,4 +45,4 @@ void LineChartCore::paint(QPainter* painter)
     paintAxisAndLines(painter, m_pointRadius);
 }
 
-#include "moc_linechartcore.cpp"
\ No newline at end of file
+#include "moc_linechartcore.cpp"
